@@ -32,6 +32,8 @@ class disableUserResponse (baseResponse):
         self.email = None
         """the user firstname"""
         self.firstname = None
+        """the boolean value representing if the updating target is in caller's child domain"""
+        self.iscallerchilddomain = None
         """the user lastname"""
         self.lastname = None
         """the secret key of the user"""
