@@ -5,16 +5,13 @@ from baseResponse import *
 class listS3sCmd (baseCmd):
     def __init__(self):
         self.isAsync = "false"
-        """The ID of the S3"""
-        """Required"""
-        self.id = None
         """List by keyword"""
         self.keyword = None
         """"""
         self.page = None
         """"""
         self.pagesize = None
-        self.required = ["id",]
+        self.required = []
 
 class listS3sResponse (baseResponse):
     def __init__(self):
