@@ -25,6 +25,4 @@ class registerSSHKeyPairResponse (baseResponse):
         self.fingerprint = None
         """Name of the keypair"""
         self.name = None
-        """Private key"""
-        self.privatekey = None
 
